Documentation
¶
Index ¶
- func Client(endpoint string, insecure bool, port string) api.HellomicroClient
- func EtagHandler(h http.Handler, minBytes int) http.Handler
- func MapSAToMapApiSA(input map[string][]string) map[string]*api.StringArray
- type MetadataFunc
- type RequestEcho
- type Service
- func (service *Service) Crash(ctx context.Context, request *empty.Empty) (*empty.Empty, error)
- func (service *Service) DeleteFile(ctx context.Context, request *api.DeleteFileReq) (*api.DeleteFileRes, error)
- func (service *Service) Echo(ctx context.Context, request *empty.Empty) (*api.EchoRes, error)
- func (service *Service) Environments(ctx context.Context, request *empty.Empty) (*api.EnvironmentsRes, error)
- func (service *Service) Exit(ctx context.Context, request *api.ExitReq) (*empty.Empty, error)
- func (service *Service) Info(ctx context.Context, request *empty.Empty) (*api.InfoRes, error)
- func (service *Service) Latency(ctx context.Context, request *api.LatencyReq) (*empty.Empty, error)
- func (service *Service) ListFiles(ctx context.Context, request *api.ListFilesReq) (*api.ListFilesRes, error)
- func (service *Service) Log(ctx context.Context, request *api.LogReq) (*empty.Empty, error)
- func (service *Service) Panic(ctx context.Context, request *empty.Empty) (*empty.Empty, error)
- func (service *Service) Ping(ctx context.Context, request *empty.Empty) (*empty.Empty, error)
- func (service *Service) ReadFile(ctx context.Context, request *api.ReadFileReq) (*api.ReadFileRes, error)
- func (service *Service) Request(ctx context.Context, request *api.RequestReq) (*api.RequestRes, error)
- func (service *Service) Run()
- func (service *Service) WriteFile(ctx context.Context, request *api.WriteFileReq) (*empty.Empty, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Client ¶
func Client(endpoint string, insecure bool, port string) api.HellomicroClient
Client returns a client for hellomicro
func EtagHandler ¶ added in v0.2.3
EtagHandler wraps an http.Handler and will write an Etag header to the response if the request method is GET and the response size is greater than or equal to minBytes. It will also return a NotModified response if the If-None-Match header matches the Etag header.
func MapSAToMapApiSA ¶
func MapSAToMapApiSA(input map[string][]string) map[string]*api.StringArray
Types ¶
type RequestEcho ¶
type Service ¶
type Service struct {
// contains filtered or unexported fields
}
func (*Service) DeleteFile ¶
func (service *Service) DeleteFile(ctx context.Context, request *api.DeleteFileReq) (*api.DeleteFileRes, error)
func (*Service) Environments ¶
func (*Service) ListFiles ¶
func (service *Service) ListFiles(ctx context.Context, request *api.ListFilesReq) (*api.ListFilesRes, error)
func (*Service) ReadFile ¶
func (service *Service) ReadFile(ctx context.Context, request *api.ReadFileReq) (*api.ReadFileRes, error)
func (*Service) Request ¶
func (service *Service) Request(ctx context.Context, request *api.RequestReq) (*api.RequestRes, error)
Click to show internal directories.
Click to hide internal directories.